/*
 * File devsrv.c
 *
 * Authors Philip Duval (DESY), Steve Herb (DESY), Marina Nikolova (EMBL),
 *    Karol Bartkiewicz (DESY), Marcus Walla (DESY), Jan Szczesny (DESY),
 *    Arthur Aghababyan (DESY), Stefan Weisse (DESY), Tobias Tempel (DESY)
 *
 * Copyright (c) Deutsches Elektronen-Synchrotron DESY 1992-2023
 *
 * The TINE .c codeset made available by open source license ultimately
 * stems from the original ISOLDE control system ((c)CERN, released under
 * a permissive CERN licence akin to the later well known MIT licence)
 * in use at CERN in 1992.  Although none of the current software is in
 * anyway a redistribution of software from the ISOLDE system of that
 * era (apart from various error/status code definitions), it does in
 * fact inherit several conceptual ideas.  We therefore owe a substantial
 * debt to CERN for its inception, and would be remiss if we did not express
 * our gratitude in the TINE open source headers.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stddef.h>
#include <stdlib.h>
#include "tine.h"

void PostSystemInit(void);
void PreSystemInit(void);

#ifndef VXWORKS
int main(int argc, char *argv[])
{
  int cc;
  switch (argc)                    /* initial debug level */
  {           /* on UNIX stations: set debug = 1 (2,or 3) */
    case 2:       /* will dynamically set the debug level */
      tineDebug = atoi(argv[1]);
      break;
    default:
      tineDebug = 0;                              /* default level */
  }
#else
int tineServer(void)
{
  int cc;
#endif
  printf("Server running (debug level %d)\n",tineDebug);

  /* init server: */
  /* call any non-default resource initialization before SystemInit(): */
  PreSystemInit();

  if ((cc=SystemInit(TRUE)) != 0) { printf("init error: %s\n",erlst[cc]); exit(1); }

  /* call FEC specific initialization: */
  PostSystemInit();

  for(;;)
  {
    SystemCycle(TRUE);
  }
  return 0;
}
